@@ -109,7 +109,9 @@ def genotype(
         avail_genes = pkg_resources.resource_listdir(
             "aldy.resources.genes", "pharmacoscan"
         )
-        avail_genes = [i[:-4] for i in avail_genes if i.endswith(".yml")]
+        avail_genes = [
+            f"pharmacoscan/{i[:-4]}" for i in avail_genes if i.endswith(".yml")
+        ]
         avail_genes = sorted(avail_genes)
     else:
         avail_genes = gene_db.lower().split(",")
@@ -176,11 +178,11 @@ def genotype(
 
     if kind == "vcf":
         log.warn("WARNING: Using VCF file. Copy-number calling is not available.")
-        profile = Profile("user_provided", cn_solution=["1", "1"])
+        profile = Profile("user_provided", cn_solution=["1", "1"], **params)
         sample = sam.Sample(gene, profile, sam_path, debug=debug)
     else:
         if cn_solution:
-            profile = Profile("user_provided", cn_solution=cn_solution)
+            profile = Profile("user_provided", cn_solution=cn_solution, **params)
         elif kind != "dump":
             if not profile_name:
                 raise AldyException("Profile not provided")
@@ -254,6 +256,8 @@ def genotype(
         log.info(f"  {i + 1:2}: {cn_sol._solution_nice()} (confidence: {conf:.0f}%)")
     log.debug("*" * 80)
 
+    # return []
+
     for i, cn_sol in enumerate(cn_sols):
         sols = major.estimate_major(
             gene,
